@@ -7,15 +7,7 @@
 #'  \item \code{SpatialPolygons*};
 #'  \item \code{sf} or \code{sfc} polygons object
 #'  }
-#' @param force_FC should the output be forced to be a \code{FeatureCollection}
-#'   even if there are no attributes? Default \code{TRUE}.
-#'   \code{FeatureCollections} are more compatible with \code{rgdal::readOGR}
-#'   and \code{geojsonio::geojson_sp}. If \code{FALSE} and there are no
-#'   attributes associated with the geometries, a \code{GeometryCollection} will
-#'   be output. Ignored for \code{Spatial} objects.
-#' @param sys Should the system mapshaper be used instead of the bundled mapshaper? Gives
-#'   better performance on large files. Requires the mapshaper node package to be installed
-#'   and on the PATH.
+#' @inheritParams apply_mapshaper_commands
 #'
 #' @return lines in the same class as the input layer, but without attributes
 #'
@@ -53,49 +45,49 @@
 #' plot(out)
 #'
 #' @export
-ms_innerlines <- function(input, force_FC = TRUE, sys = FALSE) {
+ms_innerlines <- function(input, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
   if (!is.logical(force_FC)) stop("force_FC must be TRUE or FALSE")
   UseMethod("ms_innerlines")
 }
 
 #' @export
-ms_innerlines.character <- function(input, force_FC = TRUE, sys = FALSE) {
+ms_innerlines.character <- function(input, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
   input <- check_character_input(input)
 
   apply_mapshaper_commands(data = input, command = "-innerlines",
-                           force_FC = force_FC, sys = sys)
+                           force_FC = force_FC, sys = sys, sys_mem = sys_mem)
 
 }
 
 #' @export
-ms_innerlines.geo_json <- function(input, force_FC = TRUE, sys = FALSE) {
+ms_innerlines.geo_json <- function(input, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
   apply_mapshaper_commands(data = input, command = "-innerlines",
-                           force_FC = force_FC, sys = sys)
+                           force_FC = force_FC, sys = sys, sys_mem = sys_mem)
 }
 
 #' @export
-ms_innerlines.geo_list <- function(input, force_FC = TRUE, sys = FALSE) {
+ms_innerlines.geo_list <- function(input, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
   geojson <- geo_list_to_json(input)
 
   ret <- apply_mapshaper_commands(data = geojson, command = "-innerlines",
-                                  force_FC = force_FC, sys = sys)
+                                  force_FC = force_FC, sys = sys, sys_mem = sys_mem)
 
   geojsonio::geojson_list(ret)
 }
 
 #' @export
-ms_innerlines.SpatialPolygons <- function(input, force_FC, sys = FALSE) {
-	ms_sp(as(input, "SpatialPolygons"), "-innerlines", sys = sys)
+ms_innerlines.SpatialPolygons <- function(input, force_FC, sys = FALSE, sys_mem = 8) {
+	ms_sp(as(input, "SpatialPolygons"), "-innerlines", sys = sys, sys_mem = sys_mem)
 }
 
 #' @export
-ms_innerlines.sf <- function(input, force_FC, sys = FALSE) {
-  ms_sf(sf::st_geometry(input), "-innerlines", sys = sys)
+ms_innerlines.sf <- function(input, force_FC, sys = FALSE, sys_mem = 8) {
+  ms_sf(sf::st_geometry(input), "-innerlines", sys = sys, sys_mem = sys_mem)
 }
 
 
 #' @export
-ms_innerlines.sfc <- function(input, force_FC, sys = FALSE) {
-  ms_sf(input, "-innerlines", sys = sys)
+ms_innerlines.sfc <- function(input, force_FC, sys = FALSE, sys_mem = 8) {
+  ms_sf(input, "-innerlines", sys = sys, sys_mem = sys_mem)
 }
 
