@@ -12,13 +12,17 @@
 #' @param sys Should the system mapshaper be used instead of the bundled mapshaper? Gives
 #'   better performance on large files. Requires the mapshaper node package to be installed
 #'   and on the PATH.
+#' @param sys_mem How much memory (in GB) should be allocated if using the system
+#'   mapshaper (`sys = TRUE`)? Default 8. Ignored if `sys = FALSE`.
 #'
 #' @return geojson
 #' @export
-apply_mapshaper_commands <- function(data, command, force_FC, sys = FALSE) {
+apply_mapshaper_commands <- function(data, command, force_FC, sys = FALSE, sys_mem = 8) {
 
   data <- as.character(data)
 
+  if (!is.numeric(sys_mem) )
+
   if (nchar(data) < 1000L && file.exists(data) && !sys) {
     stop("'data' points to a file on disk but you did not specify to use
          the system mapshaper. To do so set sys = TRUE")
@@ -38,7 +42,7 @@ apply_mapshaper_commands <- function(data, command, force_FC, sys = FALSE) {
   command <- paste(ms_compact(command), collapse = " ")
 
   if (sys) {
-    ret <- sys_mapshaper(data = data, command = command)
+    ret <- sys_mapshaper(data = data, command = command, sys_mem = sys_mem)
   } else {
     ms <- ms_make_ctx()
 
@@ -70,20 +74,21 @@ ms_make_ctx <- function() {
   ctx
 }
 
-sys_mapshaper <- function(data, data2 = NULL, command) {
-  check_sys_mapshaper(verbose = FALSE)
+sys_mapshaper <- function(data, data2 = NULL, command, sys_mem = 8) {
+  # Get full path to sys mapshaper, use mapshaper-xl
+  ms_path <- paste0(check_sys_mapshaper("mapshaper-xl", verbose = FALSE))
 
   # Check if need to read/write the file or if it's been written already
   # by write_sf or writeOGR
   read_write <- !file.exists(data)
 
   if (read_write) {
-    in_data_file <- tempfile(fileext = ".geojson")
+    in_data_file <- temp_geojson()
     readr::write_file(data, in_data_file)
     on.exit(unlink(in_data_file))
 
     if (!is.null(data2)) {
-      in_data_file2 <- tempfile(fileext = ".geojson")
+      in_data_file2 <- temp_geojson()
       readr::write_file(data2, in_data_file2)
       on.exit(unlink(in_data_file2), add = TRUE)
     }
@@ -93,13 +98,13 @@ sys_mapshaper <- function(data, data2 = NULL, command) {
     in_data_file2 <- data2
   }
 
-  out_data_file <- tempfile(fileext = ".geojson")
+  out_data_file <- temp_geojson()
   if (!is.null(data2)) {
-    cmd <- paste("mapshaper", in_data_file, command, in_data_file2, "-o", out_data_file)
+    cmd_args <- c(sys_mem, shQuote(in_data_file), command, shQuote(in_data_file2), "-o", shQuote(out_data_file))
   } else {
-    cmd <- paste("mapshaper", in_data_file, command, "-o", out_data_file)
+    cmd_args <- c(sys_mem, shQuote(in_data_file), command, "-o", shQuote(out_data_file))
   }
-  suppressMessages(system(cmd))
+  system2(ms_path, cmd_args)
 
   if (read_write) {
     on.exit(unlink(out_data_file), add = TRUE)
@@ -125,7 +130,7 @@ return_data = data;
 }"
 }
 
-ms_sp <- function(input, call, sys = FALSE) {
+ms_sp <- function(input, call, sys = FALSE, sys_mem = 8) {
 
   has_data <- .hasSlot(input, "data")
   if (has_data) {
@@ -134,7 +139,7 @@ ms_sp <- function(input, call, sys = FALSE) {
 
   geojson <- sp_to_GeoJSON(input, file = sys)
 
-  ret <- apply_mapshaper_commands(data = geojson, command = call, force_FC = TRUE, sys = sys)
+  ret <- apply_mapshaper_commands(data = geojson, command = call, force_FC = TRUE, sys = sys, sys_mem = sys_mem)
 
   if (!sys & grepl('^\\{"type":"GeometryCollection"', ret)) {
     stop("Cannot convert result to a Spatial* object.
@@ -172,7 +177,7 @@ sp_to_GeoJSON <- function(sp, file = FALSE){
 }
 
 ## Utilties for sf
-ms_sf <- function(input, call, sys = FALSE) {
+ms_sf <- function(input, call, sys = FALSE, sys_mem = 8) {
 
   has_data <- is(input, "sf")
   if (has_data) {
@@ -184,7 +189,7 @@ ms_sf <- function(input, call, sys = FALSE) {
 
   geojson <- sf_to_GeoJSON(input, file = sys)
 
-  ret <- apply_mapshaper_commands(data = geojson, command = call, force_FC = TRUE, sys = sys)
+  ret <- apply_mapshaper_commands(data = geojson, command = call, force_FC = TRUE, sys = sys, sys_mem = sys_mem)
 
   if (!sys & grepl('^\\{"type":"GeometryCollection"', ret)) {
     stop("Cannot convert result to an sf object.
@@ -241,26 +246,27 @@ geo_list_to_json <- function(x) {
 
 sf_sp_to_tempfile <- function(obj) {
   path <- suppressMessages(
-    geojsonio::geojson_write(obj, file = tempfile(fileext = ".geojson"))
+    geojsonio::geojson_write(obj, file = temp_geojson())
     )
   normalizePath(path[["path"]], winslash = "/", mustWork = TRUE)
 }
 
 #' Check the system mapshaper
 #'
+#' @param command either "mapshaper-xl" (default) or "mapshaper"
 #' @param verbose Print a message stating mapshaper's current version? Default `TRUE`
 #'
 #' @return TRUE (with a message) if appropriate version is installed, otherwise throws an error
 #' @export
-check_sys_mapshaper <- function(verbose = TRUE) {
-  if (!nzchar(Sys.which("mapshaper"))) {
-    stop("The mapshaper node library must be installed and on your path.\n",
-         "Install node.js (https://nodejs.org/en/) and then install mapshaper with:\n
-         npm install -g mapshaper")
+check_sys_mapshaper <- function(command = "mapshaper-xl", verbose = TRUE) {
+  if (!command %in% c("mapshaper-xl", "mapshaper")) {
+    stop("command must be one of 'mapshaper-xl' or 'mapshaper'", call. = FALSE)
   }
 
-  sys_ms_version <- package_version(system("mapshaper --version 2>&1", intern = TRUE))
-  min_ms_version <- package_version("0.4.0") # Update when updating bundled mapshaper.js
+  ms_path <- sys_ms_path(command)
+
+  sys_ms_version <- package_version(sys_ms_version())
+  min_ms_version <- package_version(bundled_ms_version()) # Update when updating bundled mapshaper.js
 
   if (sys_ms_version < min_ms_version) {
     stop("You need to upgrade your system mapshaper library.\n",
@@ -269,7 +275,36 @@ check_sys_mapshaper <- function(verbose = TRUE) {
   if (verbose) {
     message("mapshaper version ", sys_ms_version, " is installed and on your PATH")
   }
-    TRUE
+    ms_path
+}
+
+sys_ms_path <- function(command) {
+  err_msg <- paste0("The mapshaper node library must be installed and on your PATH.\n",
+                    "Install node.js (https://nodejs.org/en/) and then install mapshaper with:\n",
+                    "    npm install -g mapshaper")
+
+  ms_path <- Sys.which(command)
+
+  if (!nzchar(ms_path)) {
+    # try to find it:
+    if (nzchar(Sys.which("npm"))) {
+      npm_prefix <- system2("npm",  "get prefix", stdout = TRUE)
+      ms_path <- file.path(npm_prefix, "bin", command)
+      if (!file.exists(ms_path)) stop(err_msg, call. = FALSE)
+    } else {
+      stop(err_msg, call. = FALSE)
+    }
+  }
+  ms_path
+}
+
+sys_ms_version <- function() {
+  system2(sys_ms_path("mapshaper"), "--version", stdout = TRUE)
+}
+
+bundled_ms_version <- function() {
+  ms <- ms_make_ctx()
+  ms$get("mapshaper.internal.VERSION")
 }
 
 ms_compact <- function(l) Filter(Negate(is.null), l)
@@ -401,3 +436,13 @@ check_v8_major_version <- function() {
   major_version <- as.integer(strsplit(engine_version, "\\.")[[1]][1])
   major_version
 }
+
+temp_geojson <- function() {
+  # This option is really just to allow testing strange paths like #107
+  tmpdir <- getOption("ms_tempdir", default = tempdir())
+  dir.create(tmpdir, showWarnings = FALSE)
+  normalizePath(tempfile(
+    tmpdir = tmpdir,
+    fileext = ".geojson"
+  ), mustWork = FALSE)
+}
