@@ -51,8 +51,7 @@ states_json %>%
 check_sys_mapshaper()
 
 ## ----eval=nzchar(Sys.which("mapshaper"))--------------------------------------
-states_simp_internal <- ms_simplify(states_sf)
 states_simp_sys <- ms_simplify(states_sf, sys = TRUE)
 
-all.equal(states_simp_internal, states_simp_sys)
+plot(states_simp_sys[, "region"])
 
